==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>工作</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>生活</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>关 闭</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>提前1天提醒</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>明天提醒</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>稍后提醒</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15分钟后</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1小时后</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4小时后</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>明天</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>日程提醒</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 至 %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">提前1天提醒</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">关 闭</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">明天提醒</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">稍后提醒</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">日程提醒</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 至 %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">今天</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">明天</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>工作</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>生活</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>关 闭</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>提前1天提醒</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>明天提醒</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>稍后提醒</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15分钟后</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1小时后</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4小时后</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>明天</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>日程提醒</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 至 %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
